# sonatype-iq-api-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.196.0-01
- Package version: 1.0.0
- Generator version: 7.16.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/sonatype-nexus-community/nexus-iq-api-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/sonatype-nexus-community/nexus-iq-api-client.git`)

Then import the package:
```python
import sonatype_iq_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sonatype_iq_api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import sonatype_iq_api_client
from sonatype_iq_api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = sonatype_iq_api_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: BasicAuth
configuration = sonatype_iq_api_client.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)


# Enter a context with an instance of the API client
with sonatype_iq_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = sonatype_iq_api_client.AdvancedSearchApi(api_client)

    try:
        api_instance.create_search_index_async()
    except ApiException as e:
        print("Exception when calling AdvancedSearchApi->create_search_index_async: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdvancedSearchApi* | [**create_search_index_async**](docs/AdvancedSearchApi.md#create_search_index_async) | **POST** /api/v2/search/advanced/index | 
*AdvancedSearchApi* | [**get_export_results**](docs/AdvancedSearchApi.md#get_export_results) | **GET** /api/v2/search/advanced/export/csv | 
*AdvancedSearchApi* | [**search_index**](docs/AdvancedSearchApi.md#search_index) | **GET** /api/v2/search/advanced | 
*ApplicationCategoriesApi* | [**add_tag**](docs/ApplicationCategoriesApi.md#add_tag) | **POST** /api/v2/applicationCategories/organization/{organizationId} | 
*ApplicationCategoriesApi* | [**delete_tag**](docs/ApplicationCategoriesApi.md#delete_tag) | **DELETE** /api/v2/applicationCategories/organization/{organizationId}/{tagId} | 
*ApplicationCategoriesApi* | [**get_applicable_tags**](docs/ApplicationCategoriesApi.md#get_applicable_tags) | **GET** /api/v2/applicationCategories/organization/{organizationId}/applicable | 
*ApplicationCategoriesApi* | [**get_applicable_tags_by_application_public_id**](docs/ApplicationCategoriesApi.md#get_applicable_tags_by_application_public_id) | **GET** /api/v2/applicationCategories/application/{applicationPublicId}/applicable | 
*ApplicationCategoriesApi* | [**get_application_applicable_tags**](docs/ApplicationCategoriesApi.md#get_application_applicable_tags) | **GET** /api/v2/applicationCategories/application/{applicationPublicId} | 
*ApplicationCategoriesApi* | [**get_applied_policy_tags**](docs/ApplicationCategoriesApi.md#get_applied_policy_tags) | **GET** /api/v2/applicationCategories/organization/{organizationId}/policy | 
*ApplicationCategoriesApi* | [**get_applied_tags**](docs/ApplicationCategoriesApi.md#get_applied_tags) | **GET** /api/v2/applicationCategories/organization/{organizationId}/applied | 
*ApplicationCategoriesApi* | [**get_tags**](docs/ApplicationCategoriesApi.md#get_tags) | **GET** /api/v2/applicationCategories/organization/{organizationId} | 
*ApplicationCategoriesApi* | [**get_tags_used_by_applications**](docs/ApplicationCategoriesApi.md#get_tags_used_by_applications) | **GET** /api/v2/applicationCategories/application | 
*ApplicationCategoriesApi* | [**update_tag**](docs/ApplicationCategoriesApi.md#update_tag) | **PUT** /api/v2/applicationCategories/organization/{organizationId} | 
*ApplicationReportDataApi* | [**get_data**](docs/ApplicationReportDataApi.md#get_data) | **GET** /api/v2/applications/{applicationPublicId}/reports/{scanId} | 
*ApplicationReportDataApi* | [**get_dependency_tree**](docs/ApplicationReportDataApi.md#get_dependency_tree) | **GET** /api/v2/applications/{applicationPublicId}/reports/{scanId}/dependencyTree | 
*ApplicationReportDataApi* | [**get_policy_violation_diff**](docs/ApplicationReportDataApi.md#get_policy_violation_diff) | **GET** /api/v2/applications/{applicationPublicId}/reports/policyViolations/diff | 
*ApplicationReportDataApi* | [**get_policy_violations1**](docs/ApplicationReportDataApi.md#get_policy_violations1) | **GET** /api/v2/applications/{applicationPublicId}/reports/{scanId}/policy | 
*ApplicationReportDataApi* | [**get_raw_data**](docs/ApplicationReportDataApi.md#get_raw_data) | **GET** /api/v2/applications/{applicationPublicId}/reports/{scanId}/raw | 
*ApplicationsApi* | [**add_application**](docs/ApplicationsApi.md#add_application) | **POST** /api/v2/applications | 
*ApplicationsApi* | [**clone_application**](docs/ApplicationsApi.md#clone_application) | **POST** /api/v2/applications/{sourceApplicationId}/clone | 
*ApplicationsApi* | [**delete_application**](docs/ApplicationsApi.md#delete_application) | **DELETE** /api/v2/applications/{applicationId} | 
*ApplicationsApi* | [**get_application**](docs/ApplicationsApi.md#get_application) | **GET** /api/v2/applications/{applicationId} | 
*ApplicationsApi* | [**get_applications**](docs/ApplicationsApi.md#get_applications) | **GET** /api/v2/applications | 
*ApplicationsApi* | [**get_applications_by_organization_id**](docs/ApplicationsApi.md#get_applications_by_organization_id) | **GET** /api/v2/applications/organization/{organizationId} | 
*ApplicationsApi* | [**move_application**](docs/ApplicationsApi.md#move_application) | **POST** /api/v2/applications/{applicationId}/move/organization/{organizationId} | 
*ApplicationsApi* | [**update_application**](docs/ApplicationsApi.md#update_application) | **PUT** /api/v2/applications/{applicationId} | 
*AuditLogsApi* | [**get_audit_logs**](docs/AuditLogsApi.md#get_audit_logs) | **GET** /api/v2/auditLogs | 
*AutoPolicyWaiverExclusionsApi* | [**add_auto_policy_waive_exclusion**](docs/AutoPolicyWaiverExclusionsApi.md#add_auto_policy_waive_exclusion) | **POST** /api/v2/autoPolicyWaiverExclusions/{ownerType}/{ownerId} | 
*AutoPolicyWaiverExclusionsApi* | [**delete_auto_policy_waiver_exclusion**](docs/AutoPolicyWaiverExclusionsApi.md#delete_auto_policy_waiver_exclusion) | **DELETE** /api/v2/autoPolicyWaiverExclusions/{ownerType}/{ownerId}/{autoPolicyWaiverId}/{autoPolicyWaiverExclusionId} | 
*AutoPolicyWaiverExclusionsApi* | [**get_auto_policy_waiver_exclusions**](docs/AutoPolicyWaiverExclusionsApi.md#get_auto_policy_waiver_exclusions) | **GET** /api/v2/autoPolicyWaiverExclusions/{ownerType}/{ownerId}/{autoPolicyWaiverId} | 
*AutoPolicyWaiversApi* | [**add_auto_policy_waiver**](docs/AutoPolicyWaiversApi.md#add_auto_policy_waiver) | **POST** /api/v2/autoPolicyWaivers/{ownerType}/{ownerId} | 
*AutoPolicyWaiversApi* | [**add_auto_policy_waivers**](docs/AutoPolicyWaiversApi.md#add_auto_policy_waivers) | **POST** /api/v2/autoPolicyWaivers/v2/{ownerType}/{ownerId} | 
*AutoPolicyWaiversApi* | [**delete_auto_policy_waiver**](docs/AutoPolicyWaiversApi.md#delete_auto_policy_waiver) | **DELETE** /api/v2/autoPolicyWaivers/{ownerType}/{ownerId}/{autoPolicyWaiverId} | 
*AutoPolicyWaiversApi* | [**get_applicable_auto_waivers**](docs/AutoPolicyWaiversApi.md#get_applicable_auto_waivers) | **GET** /api/v2/autoPolicyWaivers/v2/{ownerType}/{ownerId}/applicableAutoWaivers | 
*AutoPolicyWaiversApi* | [**get_auto_policy_waiver**](docs/AutoPolicyWaiversApi.md#get_auto_policy_waiver) | **GET** /api/v2/autoPolicyWaivers/{ownerType}/{ownerId}/{autoPolicyWaiverId} | 
*AutoPolicyWaiversApi* | [**get_auto_policy_waiver_status**](docs/AutoPolicyWaiversApi.md#get_auto_policy_waiver_status) | **GET** /api/v2/autoPolicyWaivers/{ownerType}/{ownerId}/status | 
*AutoPolicyWaiversApi* | [**get_auto_policy_waivers**](docs/AutoPolicyWaiversApi.md#get_auto_policy_waivers) | **GET** /api/v2/autoPolicyWaivers/{ownerType}/{ownerId} | 
*AutoPolicyWaiversApi* | [**update_auto_policy_waiver**](docs/AutoPolicyWaiversApi.md#update_auto_policy_waiver) | **PUT** /api/v2/autoPolicyWaivers/{ownerType}/{ownerId}/{autoPolicyWaiverId} | 
*CPEMatchingConfigurationApi* | [**get_cpe_matching_configuration**](docs/CPEMatchingConfigurationApi.md#get_cpe_matching_configuration) | **GET** /api/v2/{ownerType}/{internalOwnerId}/configuration/publicSource/cpe | 
*CPEMatchingConfigurationApi* | [**update_cpe_matching_configuration**](docs/CPEMatchingConfigurationApi.md#update_cpe_matching_configuration) | **PUT** /api/v2/{ownerType}/{internalOwnerId}/configuration/publicSource/cpe | 
*ClaimComponentsApi* | [**delete**](docs/ClaimComponentsApi.md#delete) | **DELETE** /api/v2/claim/components/{hash} | 
*ClaimComponentsApi* | [**get**](docs/ClaimComponentsApi.md#get) | **GET** /api/v2/claim/components/{hash} | 
*ClaimComponentsApi* | [**get_all**](docs/ClaimComponentsApi.md#get_all) | **GET** /api/v2/claim/components | 
*ClaimComponentsApi* | [**set**](docs/ClaimComponentsApi.md#set) | **POST** /api/v2/claim/components | 
*ComponentLabelsApi* | [**add_label**](docs/ComponentLabelsApi.md#add_label) | **POST** /api/v2/labels/{ownerType}/{ownerId} | 
*ComponentLabelsApi* | [**delete_label**](docs/ComponentLabelsApi.md#delete_label) | **DELETE** /api/v2/labels/{ownerType}/{ownerId}/{labelId} | 
*ComponentLabelsApi* | [**get_applicable_contexts**](docs/ComponentLabelsApi.md#get_applicable_contexts) | **GET** /api/v2/labels/{ownerType}/{ownerId}/applicable/context/{labelId} | 
*ComponentLabelsApi* | [**get_applicable_labels**](docs/ComponentLabelsApi.md#get_applicable_labels) | **GET** /api/v2/labels/{ownerType}/{ownerId}/applicable | 
*ComponentLabelsApi* | [**get_labels**](docs/ComponentLabelsApi.md#get_labels) | **GET** /api/v2/labels/{ownerType}/{ownerId} | 
*ComponentLabelsApi* | [**update_label**](docs/ComponentLabelsApi.md#update_label) | **PUT** /api/v2/labels/{ownerType}/{ownerId} | 
*ComponentSearchApi* | [**search_component**](docs/ComponentSearchApi.md#search_component) | **GET** /api/v2/search/component | 
*ComponentsApi* | [**delete_component_label**](docs/ComponentsApi.md#delete_component_label) | **DELETE** /api/v2/components/{componentHash}/labels/{labelName}/{ownerType}s/{internalOwnerId} | 
*ComponentsApi* | [**get_component_details**](docs/ComponentsApi.md#get_component_details) | **POST** /api/v2/components/details | 
*ComponentsApi* | [**get_component_versions**](docs/ComponentsApi.md#get_component_versions) | **POST** /api/v2/components/versions | 
*ComponentsApi* | [**get_suggested_remediation_for_component**](docs/ComponentsApi.md#get_suggested_remediation_for_component) | **POST** /api/v2/components/remediation/{ownerType}/{ownerId} | 
*ComponentsApi* | [**set_component_label**](docs/ComponentsApi.md#set_component_label) | **POST** /api/v2/components/{componentHash}/labels/{labelName}/{ownerType}s/{internalOwnerId} | 
*CompositeSourceControlApi* | [**get_composite_source_control_by_owner**](docs/CompositeSourceControlApi.md#get_composite_source_control_by_owner) | **GET** /api/v2/compositeSourceControl/{ownerType}/{internalOwnerId} | 
*CompositeSourceControlValidatorApi* | [**validate_source_control_config**](docs/CompositeSourceControlValidatorApi.md#validate_source_control_config) | **GET** /api/v2/compositeSourceControlConfigValidator/application/{applicationId} | 
*ConfigCrowdApi* | [**delete_crowd_configuration**](docs/ConfigCrowdApi.md#delete_crowd_configuration) | **DELETE** /api/v2/config/crowd | 
*ConfigCrowdApi* | [**get_crowd_configuration**](docs/ConfigCrowdApi.md#get_crowd_configuration) | **GET** /api/v2/config/crowd | 
*ConfigCrowdApi* | [**insert_or_update_crowd_configuration**](docs/ConfigCrowdApi.md#insert_or_update_crowd_configuration) | **PUT** /api/v2/config/crowd | 
*ConfigCrowdApi* | [**test_crowd_configuration**](docs/ConfigCrowdApi.md#test_crowd_configuration) | **POST** /api/v2/config/crowd/test | 
*ConfigJiraApi* | [**delete_configuration1**](docs/ConfigJiraApi.md#delete_configuration1) | **DELETE** /api/v2/config/jira | 
*ConfigJiraApi* | [**get_configuration1**](docs/ConfigJiraApi.md#get_configuration1) | **GET** /api/v2/config/jira | 
*ConfigJiraApi* | [**set_configuration1**](docs/ConfigJiraApi.md#set_configuration1) | **PUT** /api/v2/config/jira | 
*ConfigMailApi* | [**delete_configuration2**](docs/ConfigMailApi.md#delete_configuration2) | **DELETE** /api/v2/config/mail | 
*ConfigMailApi* | [**get_configuration2**](docs/ConfigMailApi.md#get_configuration2) | **GET** /api/v2/config/mail | 
*ConfigMailApi* | [**set_configuration2**](docs/ConfigMailApi.md#set_configuration2) | **PUT** /api/v2/config/mail | 
*ConfigMailApi* | [**test_configuration**](docs/ConfigMailApi.md#test_configuration) | **POST** /api/v2/config/mail/test/{recipientEmail} | 
*ConfigProxyServerApi* | [**delete_configuration3**](docs/ConfigProxyServerApi.md#delete_configuration3) | **DELETE** /api/v2/config/httpProxyServer | 
*ConfigProxyServerApi* | [**get_configuration3**](docs/ConfigProxyServerApi.md#get_configuration3) | **GET** /api/v2/config/httpProxyServer | 
*ConfigProxyServerApi* | [**set_configuration3**](docs/ConfigProxyServerApi.md#set_configuration3) | **PUT** /api/v2/config/httpProxyServer | 
*ConfigReverseProxyAuthenticationApi* | [**delete_configuration4**](docs/ConfigReverseProxyAuthenticationApi.md#delete_configuration4) | **DELETE** /api/v2/config/reverseProxyAuthentication | 
*ConfigReverseProxyAuthenticationApi* | [**get_configuration4**](docs/ConfigReverseProxyAuthenticationApi.md#get_configuration4) | **GET** /api/v2/config/reverseProxyAuthentication | 
*ConfigReverseProxyAuthenticationApi* | [**set_configuration4**](docs/ConfigReverseProxyAuthenticationApi.md#set_configuration4) | **PUT** /api/v2/config/reverseProxyAuthentication | 
*ConfigSAMLApi* | [**delete_saml_configuration**](docs/ConfigSAMLApi.md#delete_saml_configuration) | **DELETE** /api/v2/config/saml | 
*ConfigSAMLApi* | [**get_metadata**](docs/ConfigSAMLApi.md#get_metadata) | **GET** /api/v2/config/saml/metadata | 
*ConfigSAMLApi* | [**get_saml_configuration**](docs/ConfigSAMLApi.md#get_saml_configuration) | **GET** /api/v2/config/saml | 
*ConfigSAMLApi* | [**insert_or_update_saml_configuration**](docs/ConfigSAMLApi.md#insert_or_update_saml_configuration) | **PUT** /api/v2/config/saml | 
*ConfigSourceControlApi* | [**delete_configuration5**](docs/ConfigSourceControlApi.md#delete_configuration5) | **DELETE** /api/v2/config/sourceControl | 
*ConfigSourceControlApi* | [**get_configuration5**](docs/ConfigSourceControlApi.md#get_configuration5) | **GET** /api/v2/config/sourceControl | 
*ConfigSourceControlApi* | [**set_configuration5**](docs/ConfigSourceControlApi.md#set_configuration5) | **PUT** /api/v2/config/sourceControl | 
*ConfigZscalerApi* | [**delete_all_categories**](docs/ConfigZscalerApi.md#delete_all_categories) | **DELETE** /api/v2/config/zscaler/update | 
*ConfigZscalerApi* | [**delete_category**](docs/ConfigZscalerApi.md#delete_category) | **DELETE** /api/v2/config/zscaler/update/{format} | 
*ConfigZscalerApi* | [**delete_configuration6**](docs/ConfigZscalerApi.md#delete_configuration6) | **DELETE** /api/v2/config/zscaler | 
*ConfigZscalerApi* | [**get_configuration6**](docs/ConfigZscalerApi.md#get_configuration6) | **GET** /api/v2/config/zscaler | 
*ConfigZscalerApi* | [**get_quota**](docs/ConfigZscalerApi.md#get_quota) | **GET** /api/v2/config/zscaler/zscalerLimits | 
*ConfigZscalerApi* | [**set_configuration6**](docs/ConfigZscalerApi.md#set_configuration6) | **PUT** /api/v2/config/zscaler | 
*ConfigZscalerApi* | [**test_configuration1**](docs/ConfigZscalerApi.md#test_configuration1) | **POST** /api/v2/config/zscaler/testConfig | 
*ConfigZscalerApi* | [**trigger_update**](docs/ConfigZscalerApi.md#trigger_update) | **POST** /api/v2/config/zscaler/update/{format} | 
*ConfigZscalerApi* | [**trigger_update_all**](docs/ConfigZscalerApi.md#trigger_update_all) | **POST** /api/v2/config/zscaler/update | 
*ConfigurationApi* | [**delete_configuration**](docs/ConfigurationApi.md#delete_configuration) | **DELETE** /api/v2/config | 
*ConfigurationApi* | [**get_configuration**](docs/ConfigurationApi.md#get_configuration) | **GET** /api/v2/config | 
*ConfigurationApi* | [**set_configuration**](docs/ConfigurationApi.md#set_configuration) | **PUT** /api/v2/config | 
*ConfigureArtifactoryConnectionApi* | [**add_artifactory_connection**](docs/ConfigureArtifactoryConnectionApi.md#add_artifactory_connection) | **POST** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId} | 
*ConfigureArtifactoryConnectionApi* | [**delete_artifactory_connection**](docs/ConfigureArtifactoryConnectionApi.md#delete_artifactory_connection) | **DELETE** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId}/{artifactoryConnectionId} | 
*ConfigureArtifactoryConnectionApi* | [**get_artifactory_connection**](docs/ConfigureArtifactoryConnectionApi.md#get_artifactory_connection) | **GET** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId}/{artifactoryConnectionId} | 
*ConfigureArtifactoryConnectionApi* | [**get_owner_artifactory_connection**](docs/ConfigureArtifactoryConnectionApi.md#get_owner_artifactory_connection) | **GET** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId} | 
*ConfigureArtifactoryConnectionApi* | [**test_artifactory_connection**](docs/ConfigureArtifactoryConnectionApi.md#test_artifactory_connection) | **POST** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId}/test | 
*ConfigureArtifactoryConnectionApi* | [**test_artifactory_connection1**](docs/ConfigureArtifactoryConnectionApi.md#test_artifactory_connection1) | **POST** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId}/{artifactoryConnectionId}/test | 
*ConfigureArtifactoryConnectionApi* | [**update_artifactory_connection**](docs/ConfigureArtifactoryConnectionApi.md#update_artifactory_connection) | **PUT** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId}/{artifactoryConnectionId} | 
*ConfigureArtifactoryConnectionApi* | [**update_owner_artifactory_connection_status**](docs/ConfigureArtifactoryConnectionApi.md#update_owner_artifactory_connection_status) | **PUT** /api/v2/config/artifactoryConnection/{ownerType}/{internalOwnerId} | 
*CycloneDXApi* | [**get_by_report_id**](docs/CycloneDXApi.md#get_by_report_id) | **GET** /api/v2/cycloneDx/{cdxVersion}/{applicationId}/reports/{reportId} | 
*CycloneDXApi* | [**get_latest**](docs/CycloneDXApi.md#get_latest) | **GET** /api/v2/cycloneDx/{cdxVersion}/{applicationId}/stages/{stageId} | 
*DataRetentionPoliciesApi* | [**get_data_retention_policies**](docs/DataRetentionPoliciesApi.md#get_data_retention_policies) | **GET** /api/v2/dataRetentionPolicies/organizations/{organizationId} | 
*DataRetentionPoliciesApi* | [**get_parent_data_retention_policies**](docs/DataRetentionPoliciesApi.md#get_parent_data_retention_policies) | **GET** /api/v2/dataRetentionPolicies/organizations/{organizationId}/parent | 
*DataRetentionPoliciesApi* | [**set_data_retention_policies**](docs/DataRetentionPoliciesApi.md#set_data_retention_policies) | **PUT** /api/v2/dataRetentionPolicies/organizations/{organizationId} | 
*DeveloperPrioritiesApi* | [**get_priorities**](docs/DeveloperPrioritiesApi.md#get_priorities) | **GET** /api/v2/developer/priorities/{applicationId}/{scanId} | 
*DeveloperPrioritiesApi* | [**get_priorities_export**](docs/DeveloperPrioritiesApi.md#get_priorities_export) | **GET** /api/v2/developer/priorities/{applicationId}/{scanId}/export | 
*EndpointsApi* | [**get_open_api**](docs/EndpointsApi.md#get_open_api) | **GET** /api/v2/endpoints/{apiType} | 
*FeatureConfigurationApi* | [**disable_feature**](docs/FeatureConfigurationApi.md#disable_feature) | **DELETE** /api/v2/config/features/{feature} | 
*FeatureConfigurationApi* | [**enabled_feature**](docs/FeatureConfigurationApi.md#enabled_feature) | **POST** /api/v2/config/features/{feature} | 
*FirewallApi* | [**add_proprietary_component_names**](docs/FirewallApi.md#add_proprietary_component_names) | **POST** /api/v2/firewall/namespace_confusion/{format} | 
*FirewallApi* | [**add_repository_manager**](docs/FirewallApi.md#add_repository_manager) | **POST** /api/v2/firewall/repositoryManagers | 
*FirewallApi* | [**add_waiver**](docs/FirewallApi.md#add_waiver) | **POST** /api/v2/firewall/container-image/{containerImageId}/policyWaiver | 
*FirewallApi* | [**configure_repositories**](docs/FirewallApi.md#configure_repositories) | **POST** /api/v2/firewall/repositories/configuration/{repositoryManagerId} | 
*FirewallApi* | [**delete_container_image_policy_waiver**](docs/FirewallApi.md#delete_container_image_policy_waiver) | **DELETE** /api/v2/firewall/container-image/{containerImageId}/policyWaiver | 
*FirewallApi* | [**delete_repository_manager**](docs/FirewallApi.md#delete_repository_manager) | **DELETE** /api/v2/firewall/repositoryManagers/{repositoryManagerId} | 
*FirewallApi* | [**evaluate_components1**](docs/FirewallApi.md#evaluate_components1) | **POST** /api/v2/firewall/components/{repositoryManagerId}/{repositoryId}/evaluate | 
*FirewallApi* | [**evaluate_malware**](docs/FirewallApi.md#evaluate_malware) | **POST** /api/v2/malware-defense/evaluate | 
*FirewallApi* | [**get_configured_repositories**](docs/FirewallApi.md#get_configured_repositories) | **GET** /api/v2/firewall/repositories/configuration/{repositoryManagerId} | 
*FirewallApi* | [**get_container_images_in_quarantine**](docs/FirewallApi.md#get_container_images_in_quarantine) | **GET** /api/v2/firewall/container-image/policyViolations/quarantined | 
*FirewallApi* | [**get_firewall_auto_unquarantine_config**](docs/FirewallApi.md#get_firewall_auto_unquarantine_config) | **GET** /api/v2/firewall/releaseQuarantine/configuration | 
*FirewallApi* | [**get_firewall_metrics**](docs/FirewallApi.md#get_firewall_metrics) | **GET** /api/v2/firewall/metrics/embedded | 
*FirewallApi* | [**get_firewall_unquarantine_summary**](docs/FirewallApi.md#get_firewall_unquarantine_summary) | **GET** /api/v2/firewall/releaseQuarantine/summary | 
*FirewallApi* | [**get_malware_defense_metrics**](docs/FirewallApi.md#get_malware_defense_metrics) | **GET** /api/v2/malware-defense/metrics | 
*FirewallApi* | [**get_quarantine_list**](docs/FirewallApi.md#get_quarantine_list) | **GET** /api/v2/firewall/components/quarantined | 
*FirewallApi* | [**get_quarantine_summary**](docs/FirewallApi.md#get_quarantine_summary) | **GET** /api/v2/firewall/quarantine/summary | 
*FirewallApi* | [**get_quarantined_component_view_anonymous_access**](docs/FirewallApi.md#get_quarantined_component_view_anonymous_access) | **GET** /api/v2/firewall/quarantinedComponentView/configuration/anonymousAccess | 
*FirewallApi* | [**get_repository_container**](docs/FirewallApi.md#get_repository_container) | **GET** /api/v2/firewall/repositoryContainer | 
*FirewallApi* | [**get_repository_manager**](docs/FirewallApi.md#get_repository_manager) | **GET** /api/v2/firewall/repositoryManagers/{repositoryManagerId} | 
*FirewallApi* | [**get_repository_managers**](docs/FirewallApi.md#get_repository_managers) | **GET** /api/v2/firewall/repositoryManagers | 
*FirewallApi* | [**get_unquarantine_list**](docs/FirewallApi.md#get_unquarantine_list) | **GET** /api/v2/firewall/components/autoReleasedFromQuarantine | 
*FirewallApi* | [**get_waivers**](docs/FirewallApi.md#get_waivers) | **GET** /api/v2/firewall/container-image/policyWaiver | 
*FirewallApi* | [**remove_proprietary_component_names**](docs/FirewallApi.md#remove_proprietary_component_names) | **DELETE** /api/v2/firewall/namespace_confusion/{format} | 
*FirewallApi* | [**set_firewall_auto_unquarantine_config**](docs/FirewallApi.md#set_firewall_auto_unquarantine_config) | **PUT** /api/v2/firewall/releaseQuarantine/configuration | 
*FirewallApi* | [**set_quarantined_component_view_anonymous_access**](docs/FirewallApi.md#set_quarantined_component_view_anonymous_access) | **PUT** /api/v2/firewall/quarantinedComponentView/configuration/anonymousAccess/{enabled} | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_application_html_report**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_application_html_report) | **GET** /api/v2/licenseLegalMetadata/application/{applicationId}/stage/{stageId}/report | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_application_report**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_application_report) | **GET** /api/v2/licenseLegalMetadata/application/{applicationId} | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_application_report1**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_application_report1) | **GET** /api/v2/licenseLegalMetadata/application/{applicationId}/stage/{stageId} | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_component_report**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_component_report) | **GET** /api/v2/licenseLegalMetadata/{ownerType}/{ownerId}/component | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_custom_application_html_report**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_custom_application_html_report) | **POST** /api/v2/licenseLegalMetadata/application/{applicationId}/stage/{stageId}/report | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_custom_application_html_report1**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_custom_application_html_report1) | **POST** /api/v2/licenseLegalMetadata/application/{applicationId}/stage/{stageId}/report/templateId/{templateId} | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_custom_multi_application_html_report1**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_custom_multi_application_html_report1) | **POST** /api/v2/licenseLegalMetadata/multiApplication/report/templateId/{templateId} | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_multi_application_html_report**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_multi_application_html_report) | **POST** /api/v2/licenseLegalMetadata/multiApplication/report | 
*LicenseLegalMetadataReportApi* | [**get_license_legal_multi_application_report_from_active_user_filter**](docs/LicenseLegalMetadataReportApi.md#get_license_legal_multi_application_report_from_active_user_filter) | **POST** /api/v2/licenseLegalMetadata/multiApplication/activeUserFilter/report/templateId/{templateId} | 
*LicenseLegalMetadataTemplateApi* | [**delete_attribution_report_template**](docs/LicenseLegalMetadataTemplateApi.md#delete_attribution_report_template) | **DELETE** /api/v2/licenseLegalMetadata/report-template/{id} | 
*LicenseLegalMetadataTemplateApi* | [**get_all_attribution_report_templates**](docs/LicenseLegalMetadataTemplateApi.md#get_all_attribution_report_templates) | **GET** /api/v2/licenseLegalMetadata/report-template | 
*LicenseLegalMetadataTemplateApi* | [**get_attribution_report_template_by_id**](docs/LicenseLegalMetadataTemplateApi.md#get_attribution_report_template_by_id) | **GET** /api/v2/licenseLegalMetadata/report-template/{id} | 
*LicenseLegalMetadataTemplateApi* | [**save_attribution_report_template**](docs/LicenseLegalMetadataTemplateApi.md#save_attribution_report_template) | **POST** /api/v2/licenseLegalMetadata/report-template | 
*LicenseOverridesApi* | [**add_license_override**](docs/LicenseOverridesApi.md#add_license_override) | **POST** /api/v2/licenseOverrides/{ownerType}/{ownerId} | 
*LicenseOverridesApi* | [**delete_license_override**](docs/LicenseOverridesApi.md#delete_license_override) | **DELETE** /api/v2/licenseOverrides/{ownerType}/{ownerId}/{licenseOverrideId} | 
*LicenseOverridesApi* | [**get_applied_license_overrides**](docs/LicenseOverridesApi.md#get_applied_license_overrides) | **GET** /api/v2/licenseOverrides/{ownerType}/{ownerId} | 
*LicenseOverridesApi* | [**get_applied_license_overrides_for_legal_reviewer**](docs/LicenseOverridesApi.md#get_applied_license_overrides_for_legal_reviewer) | **GET** /api/v2/licenseOverrides/{ownerType}/{ownerId}/legalReviewer | 
*OrganizationsApi* | [**add_organization**](docs/OrganizationsApi.md#add_organization) | **POST** /api/v2/organizations | 
*OrganizationsApi* | [**delete_organization**](docs/OrganizationsApi.md#delete_organization) | **DELETE** /api/v2/organizations/{organizationId} | 
*OrganizationsApi* | [**get_organization**](docs/OrganizationsApi.md#get_organization) | **GET** /api/v2/organizations/{organizationId} | 
*OrganizationsApi* | [**get_organizations**](docs/OrganizationsApi.md#get_organizations) | **GET** /api/v2/organizations | 
*OrganizationsApi* | [**move_organization**](docs/OrganizationsApi.md#move_organization) | **PUT** /api/v2/organizations/{organizationId}/move/destination/{destinationId} | 
*PoliciesApi* | [**get_policies**](docs/PoliciesApi.md#get_policies) | **GET** /api/v2/policies | 
*PolicyEvaluationApi* | [**evaluate_components**](docs/PolicyEvaluationApi.md#evaluate_components) | **POST** /api/v2/evaluation/applications/{applicationId} | 
*PolicyEvaluationApi* | [**evaluate_source_control**](docs/PolicyEvaluationApi.md#evaluate_source_control) | **POST** /api/v2/evaluation/applications/{applicationId}/sourceControlEvaluation | 
*PolicyEvaluationApi* | [**get_application_evaluation_status**](docs/PolicyEvaluationApi.md#get_application_evaluation_status) | **GET** /api/v2/evaluation/applications/{applicationId}/status/{statusId} | 
*PolicyEvaluationApi* | [**get_component_evaluation**](docs/PolicyEvaluationApi.md#get_component_evaluation) | **GET** /api/v2/evaluation/applications/{applicationId}/results/{resultId} | 
*PolicyEvaluationApi* | [**promote_scan**](docs/PolicyEvaluationApi.md#promote_scan) | **POST** /api/v2/evaluation/applications/{applicationId}/promoteScan | 
*PolicyViolationDetailsApi* | [**get_applicable_auto_waiver**](docs/PolicyViolationDetailsApi.md#get_applicable_auto_waiver) | **GET** /api/v2/policyViolations/{violationId}/applicableAutoWaiver | 
*PolicyViolationDetailsApi* | [**get_applicable_waiver_requests**](docs/PolicyViolationDetailsApi.md#get_applicable_waiver_requests) | **GET** /api/v2/policyViolations/{violationId}/applicableWaiverRequests | 
*PolicyViolationDetailsApi* | [**get_applicable_waivers**](docs/PolicyViolationDetailsApi.md#get_applicable_waivers) | **GET** /api/v2/policyViolations/{violationId}/applicableWaivers | 
*PolicyViolationDetailsApi* | [**get_cross_stage_policy_violation_by_constituent_id**](docs/PolicyViolationDetailsApi.md#get_cross_stage_policy_violation_by_constituent_id) | **GET** /api/v2/policyViolations/crossStage | 
*PolicyViolationDetailsApi* | [**get_cross_stage_policy_violation_by_id**](docs/PolicyViolationDetailsApi.md#get_cross_stage_policy_violation_by_id) | **GET** /api/v2/policyViolations/crossStage/{violationId} | 
*PolicyViolationDetailsApi* | [**get_policy_violations**](docs/PolicyViolationDetailsApi.md#get_policy_violations) | **GET** /api/v2/policyViolations | 
*PolicyViolationDetailsApi* | [**get_similar_waivers**](docs/PolicyViolationDetailsApi.md#get_similar_waivers) | **GET** /api/v2/policyViolations/{violationId}/similarWaivers | 
*PolicyViolationDetailsApi* | [**get_transitive_policy_violations_by_app_scan_component**](docs/PolicyViolationDetailsApi.md#get_transitive_policy_violations_by_app_scan_component) | **GET** /api/v2/policyViolations/transitive/{ownerType}/{ownerId}/{scanId} | 
*PolicyViolationDetailsApi* | [**get_transitive_policy_violations_by_owner_stage_component**](docs/PolicyViolationDetailsApi.md#get_transitive_policy_violations_by_owner_stage_component) | **GET** /api/v2/policyViolations/transitive/{ownerType}/{ownerId}/stages/{stageId} | 
*PolicyWaiverReasonsApi* | [**get_policy_waiver_reasons**](docs/PolicyWaiverReasonsApi.md#get_policy_waiver_reasons) | **GET** /api/v2/policyWaiverReasons | 
*PolicyWaiverRequestsApi* | [**add_policy_waiver_request_by_policy_violation_id**](docs/PolicyWaiverRequestsApi.md#add_policy_waiver_request_by_policy_violation_id) | **POST** /api/v2/policyWaiverRequests/{ownerType}/{ownerId}/policyViolation/{policyViolationId} | 
*PolicyWaiverRequestsApi* | [**get_policy_waiver_request**](docs/PolicyWaiverRequestsApi.md#get_policy_waiver_request) | **GET** /api/v2/policyWaiverRequests/{ownerType}/{ownerId}/{policyWaiverRequestId} | 
*PolicyWaiverRequestsApi* | [**review_policy_waiver_request**](docs/PolicyWaiverRequestsApi.md#review_policy_waiver_request) | **POST** /api/v2/policyWaiverRequests/{ownerType}/{ownerId}/review/{policyWaiverRequestId} | 
*PolicyWaiverRequestsApi* | [**update_policy_waiver_request**](docs/PolicyWaiverRequestsApi.md#update_policy_waiver_request) | **PUT** /api/v2/policyWaiverRequests/{ownerType}/{ownerId}/{policyWaiverRequestId} | 
*PolicyWaiversApi* | [**add_bulk_policy_waivers**](docs/PolicyWaiversApi.md#add_bulk_policy_waivers) | **POST** /api/v2/policyWaivers/{ownerType}/{ownerId} | 
*PolicyWaiversApi* | [**add_policy_waiver_by_policy_violation_id**](docs/PolicyWaiversApi.md#add_policy_waiver_by_policy_violation_id) | **POST** /api/v2/policyWaivers/{ownerType}/{ownerId}/{policyViolationId} | 
*PolicyWaiversApi* | [**add_waiver_to_transitive_policy_violations_by_app_scan_component**](docs/PolicyWaiversApi.md#add_waiver_to_transitive_policy_violations_by_app_scan_component) | **POST** /api/v2/policyWaivers/transitive/{ownerType}/{ownerId}/{scanId} | 
*PolicyWaiversApi* | [**add_waiver_to_transitive_policy_violations_by_owner_stage_component**](docs/PolicyWaiversApi.md#add_waiver_to_transitive_policy_violations_by_owner_stage_component) | **POST** /api/v2/policyWaivers/transitive/{ownerType}/{ownerId}/stages/{stageId} | 
*PolicyWaiversApi* | [**delete_policy_waiver**](docs/PolicyWaiversApi.md#delete_policy_waiver) | **DELETE** /api/v2/policyWaivers/{ownerType}/{ownerId}/{policyWaiverId} | 
*PolicyWaiversApi* | [**get_policy_waiver**](docs/PolicyWaiversApi.md#get_policy_waiver) | **GET** /api/v2/policyWaivers/{ownerType}/{ownerId}/{policyWaiverId} | 
*PolicyWaiversApi* | [**get_policy_waivers**](docs/PolicyWaiversApi.md#get_policy_waivers) | **GET** /api/v2/policyWaivers/{ownerType}/{ownerId} | 
*PolicyWaiversApi* | [**get_transitive_policy_waivers_by_app_scan_component**](docs/PolicyWaiversApi.md#get_transitive_policy_waivers_by_app_scan_component) | **GET** /api/v2/policyWaivers/transitive/{ownerType}/{ownerId}/{scanId} | 
*PolicyWaiversApi* | [**request_policy_waiver**](docs/PolicyWaiversApi.md#request_policy_waiver) | **POST** /api/v2/policyWaivers/waiverRequests/{policyViolationId} | 
*PolicyWaiversApi* | [**update_policy_waiver**](docs/PolicyWaiversApi.md#update_policy_waiver) | **PUT** /api/v2/policyWaivers/{ownerType}/{ownerId}/{policyWaiverId} | 
*ProductLicenseApi* | [**install_license**](docs/ProductLicenseApi.md#install_license) | **POST** /api/v2/product/license | 
*ProductLicenseApi* | [**uninstall_license**](docs/ProductLicenseApi.md#uninstall_license) | **DELETE** /api/v2/product/license | 
*ReportsApi* | [**get_all1**](docs/ReportsApi.md#get_all1) | **GET** /api/v2/reports/applications | 
*ReportsApi* | [**get_by_application_id**](docs/ReportsApi.md#get_by_application_id) | **GET** /api/v2/reports/applications/{applicationId} | 
*ReportsApi* | [**get_components_in_quarantine**](docs/ReportsApi.md#get_components_in_quarantine) | **GET** /api/v2/reports/components/quarantined | 
*ReportsApi* | [**get_components_with_waivers**](docs/ReportsApi.md#get_components_with_waivers) | **GET** /api/v2/reports/components/waivers | 
*ReportsApi* | [**get_metrics**](docs/ReportsApi.md#get_metrics) | **POST** /api/v2/reports/metrics | 
*ReportsApi* | [**get_report_history_for_application**](docs/ReportsApi.md#get_report_history_for_application) | **GET** /api/v2/reports/applications/{applicationId}/history | 
*ReportsApi* | [**get_stale_waivers**](docs/ReportsApi.md#get_stale_waivers) | **GET** /api/v2/reports/waivers/stale | 
*RepositoriesApi* | [**get_quarantined_by_path**](docs/RepositoriesApi.md#get_quarantined_by_path) | **POST** /api/v2/repositories/{repositoryManagerInstanceId}/{repositoryPublicId}/components/quarantined/pathnames | 
*RepositoriesApi* | [**release_quarantine_without_re_eval**](docs/RepositoriesApi.md#release_quarantine_without_re_eval) | **POST** /api/v2/repositories/quarantine/{quarantineId}/release | 
*RoleMembershipsApi* | [**get_role_memberships_application_or_organization**](docs/RoleMembershipsApi.md#get_role_memberships_application_or_organization) | **GET** /api/v2/roleMemberships/{ownerType}/{internalOwnerId} | 
*RoleMembershipsApi* | [**get_role_memberships_global_or_repository_container**](docs/RoleMembershipsApi.md#get_role_memberships_global_or_repository_container) | **GET** /api/v2/roleMemberships/{ownerType} | 
*RoleMembershipsApi* | [**grant_role_membership_application_or_organization**](docs/RoleMembershipsApi.md#grant_role_membership_application_or_organization) | **PUT** /api/v2/roleMemberships/{ownerType}/{internalOwnerId}/role/{roleId}/{memberType}/{memberName} | 
*RoleMembershipsApi* | [**grant_role_membership_global_or_repository_container**](docs/RoleMembershipsApi.md#grant_role_membership_global_or_repository_container) | **PUT** /api/v2/roleMemberships/{ownerType}/role/{roleId}/{memberType}/{memberName} | 
*RoleMembershipsApi* | [**revoke_role_membership_application_or_organization**](docs/RoleMembershipsApi.md#revoke_role_membership_application_or_organization) | **DELETE** /api/v2/roleMemberships/{ownerType}/{internalOwnerId}/role/{roleId}/{memberType}/{memberName} | 
*RoleMembershipsApi* | [**revoke_role_membership_global_or_repository_container**](docs/RoleMembershipsApi.md#revoke_role_membership_global_or_repository_container) | **DELETE** /api/v2/roleMemberships/{ownerType}/role/{roleId}/{memberType}/{memberName} | 
*RolesApi* | [**get_roles**](docs/RolesApi.md#get_roles) | **GET** /api/v2/roles | 
*SBOMApi* | [**delete_sbom_version**](docs/SBOMApi.md#delete_sbom_version) | **DELETE** /api/v2/sbom/applications/{applicationId}/versions/{version} | Delete sbom version
*SBOMApi* | [**delete_vulnerability_analysis**](docs/SBOMApi.md#delete_vulnerability_analysis) | **DELETE** /api/v2/sbom/applications/{applicationId}/versions/{version}/vulnerability/{refId}/analysis | Deletes a Vulnerability analysis for a given component.
*SBOMApi* | [**get_active_sbom_version_list_by_application**](docs/SBOMApi.md#get_active_sbom_version_list_by_application) | **GET** /api/v2/sbom/applications/{applicationId}/versions | Gets a list of active sbom versions by application id
*SBOMApi* | [**get_import_status**](docs/SBOMApi.md#get_import_status) | **GET** /api/v2/sbom/applications/{applicationId}/status/{importRequestId} | Get sbom import status
*SBOMApi* | [**get_sbom_components**](docs/SBOMApi.md#get_sbom_components) | **GET** /api/v2/sbom/applications/{applicationId}/versions/{version}/components | Gets the components found in a specific sbom version
*SBOMApi* | [**get_sbom_metadata_summary_for_application**](docs/SBOMApi.md#get_sbom_metadata_summary_for_application) | **GET** /api/v2/sbom/applications/{applicationId} | Gets a paginated list of SBOMs for an application
*SBOMApi* | [**get_sbom_version**](docs/SBOMApi.md#get_sbom_version) | **GET** /api/v2/sbom/applications/{applicationId}/versions/{version} | Gets a sbom version
*SBOMApi* | [**get_vulnerability_details**](docs/SBOMApi.md#get_vulnerability_details) | **GET** /api/v2/sbom/applications/{applicationId}/versions/{version}/vulnerability/{refId} | 
*SBOMApi* | [**import_sbom**](docs/SBOMApi.md#import_sbom) | **POST** /api/v2/sbom/import | Import a new sbom version
*SBOMApi* | [**save_vulnerability_analysis**](docs/SBOMApi.md#save_vulnerability_analysis) | **PUT** /api/v2/sbom/applications/{applicationId}/versions/{version}/vulnerability/{refId}/analysis | Updates a vulnerability analysis annotation for a specific SBOM vulnerability
*SPDXApi* | [**get_by_scan_id**](docs/SPDXApi.md#get_by_scan_id) | **GET** /api/v2/spdx/{applicationId}/reports/{scanId} | 
*SPDXApi* | [**get_latest_for_stage**](docs/SPDXApi.md#get_latest_for_stage) | **GET** /api/v2/spdx/{applicationId}/stages/{stageId} | 
*SecurityVulnerabilityOverridesApi* | [**get_security_vulnerability_overrides**](docs/SecurityVulnerabilityOverridesApi.md#get_security_vulnerability_overrides) | **GET** /api/v2/securityOverrides | 
*SolutionsApi* | [**get_licensed_solutions**](docs/SolutionsApi.md#get_licensed_solutions) | **GET** /api/v2/solutions/licensed | 
*SourceControlApi* | [**add_source_control**](docs/SourceControlApi.md#add_source_control) | **POST** /api/v2/sourceControl/{ownerType}/{internalOwnerId} | 
*SourceControlApi* | [**add_user_mappings**](docs/SourceControlApi.md#add_user_mappings) | **POST** /api/v2/sourceControl/automaticRoleAssignment/userMappings/{organizationId} | 
*SourceControlApi* | [**automatic_role_assignment**](docs/SourceControlApi.md#automatic_role_assignment) | **POST** /api/v2/sourceControl/automaticRoleAssignment/{publicId} | 
*SourceControlApi* | [**delete_source_control**](docs/SourceControlApi.md#delete_source_control) | **DELETE** /api/v2/sourceControl/{ownerType}/{internalOwnerId} | 
*SourceControlApi* | [**delete_user_mappings**](docs/SourceControlApi.md#delete_user_mappings) | **DELETE** /api/v2/sourceControl/automaticRoleAssignment/userMappings/{organizationId} | 
*SourceControlApi* | [**get_source_control1**](docs/SourceControlApi.md#get_source_control1) | **GET** /api/v2/sourceControl/{ownerType}/{internalOwnerId} | 
*SourceControlApi* | [**get_user_mappings_by_owner**](docs/SourceControlApi.md#get_user_mappings_by_owner) | **GET** /api/v2/sourceControl/automaticRoleAssignment/userMappings/{ownerType}/{internalOwnerId} | 
*SourceControlApi* | [**update_source_control**](docs/SourceControlApi.md#update_source_control) | **PUT** /api/v2/sourceControl/{ownerType}/{internalOwnerId} | 
*SourceControlMetricsApi* | [**get_source_control**](docs/SourceControlMetricsApi.md#get_source_control) | **GET** /api/v2/sourceControlMetrics/{ownerType}/{internalOwnerId} | 
*ThirdPartyAnalysisApi* | [**get_scan_status**](docs/ThirdPartyAnalysisApi.md#get_scan_status) | **GET** /api/v2/scan/applications/{applicationId}/status/{scanRequestId} | 
*ThirdPartyAnalysisApi* | [**scan_components**](docs/ThirdPartyAnalysisApi.md#scan_components) | **POST** /api/v2/scan/applications/{applicationId}/sources/{source} | 
*UserTokensApi* | [**create_user_token**](docs/UserTokensApi.md#create_user_token) | **POST** /api/v2/userTokens/currentUser | 
*UserTokensApi* | [**delete_current_user_token**](docs/UserTokensApi.md#delete_current_user_token) | **DELETE** /api/v2/userTokens/currentUser | 
*UserTokensApi* | [**delete_user_token_by_user_code**](docs/UserTokensApi.md#delete_user_token_by_user_code) | **DELETE** /api/v2/userTokens/userCode/{userCode} | 
*UserTokensApi* | [**get_user_token_by_username_and_realm_id**](docs/UserTokensApi.md#get_user_token_by_username_and_realm_id) | **GET** /api/v2/userTokens/{username} | 
*UserTokensApi* | [**get_user_token_exists_for_current_user**](docs/UserTokensApi.md#get_user_token_exists_for_current_user) | **GET** /api/v2/userTokens/currentUser/hasToken | 
*UserTokensApi* | [**get_user_tokens_by_created_between_and_realm_id**](docs/UserTokensApi.md#get_user_tokens_by_created_between_and_realm_id) | **GET** /api/v2/userTokens | 
*UserTokensApi* | [**purge_user_tokens**](docs/UserTokensApi.md#purge_user_tokens) | **DELETE** /api/v2/userTokens/purge | 
*UsersApi* | [**add**](docs/UsersApi.md#add) | **POST** /api/v2/users | 
*UsersApi* | [**delete1**](docs/UsersApi.md#delete1) | **DELETE** /api/v2/users/{username} | 
*UsersApi* | [**get1**](docs/UsersApi.md#get1) | **GET** /api/v2/users/{username} | 
*UsersApi* | [**get_all2**](docs/UsersApi.md#get_all2) | **GET** /api/v2/users | 
*UsersApi* | [**update**](docs/UsersApi.md#update) | **PUT** /api/v2/users/{username} | 
*VulnerabilityDetailsApi* | [**get_security_vulnerability_details**](docs/VulnerabilityDetailsApi.md#get_security_vulnerability_details) | **POST** /api/v2/vulnerabilities | 
*VulnerabilityDetailsApi* | [**get_security_vulnerability_details1**](docs/VulnerabilityDetailsApi.md#get_security_vulnerability_details1) | **GET** /api/v2/vulnerabilities/{refId} | 


## Documentation For Models

 - [Action](docs/Action.md)
 - [ApiApplicationBaseDTO](docs/ApiApplicationBaseDTO.md)
 - [ApiApplicationCategoriesDTO](docs/ApiApplicationCategoriesDTO.md)
 - [ApiApplicationCategoriesListDTO](docs/ApiApplicationCategoriesListDTO.md)
 - [ApiApplicationCategoryDTO](docs/ApiApplicationCategoryDTO.md)
 - [ApiApplicationDTO](docs/ApiApplicationDTO.md)
 - [ApiApplicationEvaluationCommitDTO](docs/ApiApplicationEvaluationCommitDTO.md)
 - [ApiApplicationEvaluationResultDTOV2](docs/ApiApplicationEvaluationResultDTOV2.md)
 - [ApiApplicationEvaluationStatusDTOV2](docs/ApiApplicationEvaluationStatusDTOV2.md)
 - [ApiApplicationListDTO](docs/ApiApplicationListDTO.md)
 - [ApiApplicationReportDTOV2](docs/ApiApplicationReportDTOV2.md)
 - [ApiApplicationTagDTO](docs/ApiApplicationTagDTO.md)
 - [ApiApplicationViolationDTOV2](docs/ApiApplicationViolationDTOV2.md)
 - [ApiApplicationViolationListDTOV2](docs/ApiApplicationViolationListDTOV2.md)
 - [ApiApplicationWaiverDTO](docs/ApiApplicationWaiverDTO.md)
 - [ApiAppliedLicenseOverridesDTO](docs/ApiAppliedLicenseOverridesDTO.md)
 - [ApiArtifactoryConnectionDTO](docs/ApiArtifactoryConnectionDTO.md)
 - [ApiArtifactoryConnectionStatusRequestDTO](docs/ApiArtifactoryConnectionStatusRequestDTO.md)
 - [ApiArtifactoryConnectionStatusResponseDTO](docs/ApiArtifactoryConnectionStatusResponseDTO.md)
 - [ApiAutoPolicyWaiverDTO](docs/ApiAutoPolicyWaiverDTO.md)
 - [ApiAutoPolicyWaiverExclusionRequestDTO](docs/ApiAutoPolicyWaiverExclusionRequestDTO.md)
 - [ApiAutoPolicyWaiverExclusionResponseDTO](docs/ApiAutoPolicyWaiverExclusionResponseDTO.md)
 - [ApiAutoPolicyWaiverStatusDTO](docs/ApiAutoPolicyWaiverStatusDTO.md)
 - [ApiBulkWaiversDTO](docs/ApiBulkWaiversDTO.md)
 - [ApiComponentChangeActionDTO](docs/ApiComponentChangeActionDTO.md)
 - [ApiComponentDTOV2](docs/ApiComponentDTOV2.md)
 - [ApiComponentDetailsDTOV2](docs/ApiComponentDetailsDTOV2.md)
 - [ApiComponentDetailsRequestDTOV2](docs/ApiComponentDetailsRequestDTOV2.md)
 - [ApiComponentDetailsResultDTOV2](docs/ApiComponentDetailsResultDTOV2.md)
 - [ApiComponentEvaluationRequestDTOV2](docs/ApiComponentEvaluationRequestDTOV2.md)
 - [ApiComponentEvaluationResultDTOV2](docs/ApiComponentEvaluationResultDTOV2.md)
 - [ApiComponentEvaluationTicketDTOV2](docs/ApiComponentEvaluationTicketDTOV2.md)
 - [ApiComponentIdentifierDTOV2](docs/ApiComponentIdentifierDTOV2.md)
 - [ApiComponentOrPurlIdentifierDTOV2](docs/ApiComponentOrPurlIdentifierDTOV2.md)
 - [ApiComponentPolicyViolationDTO](docs/ApiComponentPolicyViolationDTO.md)
 - [ApiComponentPolicyViolationListDTOV2](docs/ApiComponentPolicyViolationListDTOV2.md)
 - [ApiComponentPolicyWaiversDTO](docs/ApiComponentPolicyWaiversDTO.md)
 - [ApiComponentProjectDataDTO](docs/ApiComponentProjectDataDTO.md)
 - [ApiComponentProjectMetadataDTO](docs/ApiComponentProjectMetadataDTO.md)
 - [ApiComponentProjectScmDTO](docs/ApiComponentProjectScmDTO.md)
 - [ApiComponentProjectScmDetailsDTO](docs/ApiComponentProjectScmDetailsDTO.md)
 - [ApiComponentProjectScmMetadataDTO](docs/ApiComponentProjectScmMetadataDTO.md)
 - [ApiComponentReleasedFromQuarantineDTO](docs/ApiComponentReleasedFromQuarantineDTO.md)
 - [ApiComponentRemediationValueDTO](docs/ApiComponentRemediationValueDTO.md)
 - [ApiComponentTransitivePolicyViolationsDTO](docs/ApiComponentTransitivePolicyViolationsDTO.md)
 - [ApiComponentWaiversDTO](docs/ApiComponentWaiversDTO.md)
 - [ApiComponentsInQuarantineDTO](docs/ApiComponentsInQuarantineDTO.md)
 - [ApiCompositeSourceControlDTO](docs/ApiCompositeSourceControlDTO.md)
 - [ApiCompositeValueDTOBoolean](docs/ApiCompositeValueDTOBoolean.md)
 - [ApiCompositeValueDTOInteger](docs/ApiCompositeValueDTOInteger.md)
 - [ApiCompositeValueDTOString](docs/ApiCompositeValueDTOString.md)
 - [ApiConditionFactReasonDTO](docs/ApiConditionFactReasonDTO.md)
 - [ApiConstraintFactDTO](docs/ApiConstraintFactDTO.md)
 - [ApiConstraintViolationDTO](docs/ApiConstraintViolationDTO.md)
 - [ApiConstraintViolationReasonDTO](docs/ApiConstraintViolationReasonDTO.md)
 - [ApiContainerImageWaiverDTO](docs/ApiContainerImageWaiverDTO.md)
 - [ApiCrossStageViolationDTOV2](docs/ApiCrossStageViolationDTOV2.md)
 - [ApiCrowdConfigurationDTO](docs/ApiCrowdConfigurationDTO.md)
 - [ApiDataRetentionPoliciesDTO](docs/ApiDataRetentionPoliciesDTO.md)
 - [ApiDependencyDataDTO](docs/ApiDependencyDataDTO.md)
 - [ApiDependencyTreeNodeDTO](docs/ApiDependencyTreeNodeDTO.md)
 - [ApiDependencyTreeResponseDTO](docs/ApiDependencyTreeResponseDTO.md)
 - [ApiEnhancedPolicyViolationDTOV2](docs/ApiEnhancedPolicyViolationDTOV2.md)
 - [ApiEvaluationResultCounterDTO](docs/ApiEvaluationResultCounterDTO.md)
 - [ApiFirewallComponentDTO](docs/ApiFirewallComponentDTO.md)
 - [ApiFirewallComponentDTOResult](docs/ApiFirewallComponentDTOResult.md)
 - [ApiFirewallMetricsResultDTO](docs/ApiFirewallMetricsResultDTO.md)
 - [ApiFirewallQuarantineSummaryDTO](docs/ApiFirewallQuarantineSummaryDTO.md)
 - [ApiFirewallQuarantinedComponentDto](docs/ApiFirewallQuarantinedComponentDto.md)
 - [ApiFirewallQuarantinedComponentDtoResult](docs/ApiFirewallQuarantinedComponentDtoResult.md)
 - [ApiFirewallReleaseQuarantineConfigDTO](docs/ApiFirewallReleaseQuarantineConfigDTO.md)
 - [ApiFirewallReleaseQuarantineSummaryDTO](docs/ApiFirewallReleaseQuarantineSummaryDTO.md)
 - [ApiGlobalInformationDTOV2](docs/ApiGlobalInformationDTOV2.md)
 - [ApiHashComponentIdentifierDTO](docs/ApiHashComponentIdentifierDTO.md)
 - [ApiHashComponentIdentifiersDTO](docs/ApiHashComponentIdentifiersDTO.md)
 - [ApiJiraConfigurationDTO](docs/ApiJiraConfigurationDTO.md)
 - [ApiLabelDTO](docs/ApiLabelDTO.md)
 - [ApiLicenseDTO](docs/ApiLicenseDTO.md)
 - [ApiLicenseDataDTO](docs/ApiLicenseDataDTO.md)
 - [ApiLicenseDataDTOV2](docs/ApiLicenseDataDTOV2.md)
 - [ApiLicenseLegalApplicationReportDTO](docs/ApiLicenseLegalApplicationReportDTO.md)
 - [ApiLicenseLegalComponentDTO](docs/ApiLicenseLegalComponentDTO.md)
 - [ApiLicenseLegalComponentReportDTO](docs/ApiLicenseLegalComponentReportDTO.md)
 - [ApiLicenseLegalCopyrightDTO](docs/ApiLicenseLegalCopyrightDTO.md)
 - [ApiLicenseLegalDataDTO](docs/ApiLicenseLegalDataDTO.md)
 - [ApiLicenseLegalFileDTO](docs/ApiLicenseLegalFileDTO.md)
 - [ApiLicenseLegalMetadataDTO](docs/ApiLicenseLegalMetadataDTO.md)
 - [ApiLicenseLegalObligationDTO](docs/ApiLicenseLegalObligationDTO.md)
 - [ApiLicenseLegalStageScanDTO](docs/ApiLicenseLegalStageScanDTO.md)
 - [ApiLicenseOverrideDTO](docs/ApiLicenseOverrideDTO.md)
 - [ApiLicenseThreatDTOV2](docs/ApiLicenseThreatDTOV2.md)
 - [ApiLicensedSolutionDTO](docs/ApiLicensedSolutionDTO.md)
 - [ApiMailConfigurationDTO](docs/ApiMailConfigurationDTO.md)
 - [ApiMalwareComponentEvaluationRequest](docs/ApiMalwareComponentEvaluationRequest.md)
 - [ApiMalwareComponentEvaluationRequestList](docs/ApiMalwareComponentEvaluationRequestList.md)
 - [ApiMatchStateSummaryDTOV2](docs/ApiMatchStateSummaryDTOV2.md)
 - [ApiMemberDTO](docs/ApiMemberDTO.md)
 - [ApiMetricsReportingAggregationDTOV2](docs/ApiMetricsReportingAggregationDTOV2.md)
 - [ApiMetricsReportingDTOV2](docs/ApiMetricsReportingDTOV2.md)
 - [ApiMetricsReportingQueryDTOV2](docs/ApiMetricsReportingQueryDTOV2.md)
 - [ApiMoveApplicationResponseDTOV2](docs/ApiMoveApplicationResponseDTOV2.md)
 - [ApiOrganizationDTO](docs/ApiOrganizationDTO.md)
 - [ApiOrganizationListDTO](docs/ApiOrganizationListDTO.md)
 - [ApiOwnerArtifactoryConnectionDTO](docs/ApiOwnerArtifactoryConnectionDTO.md)
 - [ApiOwnerDTO](docs/ApiOwnerDTO.md)
 - [ApiPageResultPrioritizedComponent](docs/ApiPageResultPrioritizedComponent.md)
 - [ApiPolicyDTO](docs/ApiPolicyDTO.md)
 - [ApiPolicyListDTO](docs/ApiPolicyListDTO.md)
 - [ApiPolicyViolationDTOV2](docs/ApiPolicyViolationDTOV2.md)
 - [ApiPolicyViolationDiffDTO](docs/ApiPolicyViolationDiffDTO.md)
 - [ApiPolicyViolationForDiffDTO](docs/ApiPolicyViolationForDiffDTO.md)
 - [ApiPolicyViolationStageDTO](docs/ApiPolicyViolationStageDTO.md)
 - [ApiPolicyWaiverDTO](docs/ApiPolicyWaiverDTO.md)
 - [ApiPolicyWaiverReasonDTO](docs/ApiPolicyWaiverReasonDTO.md)
 - [ApiPolicyWaiverRequestDTO](docs/ApiPolicyWaiverRequestDTO.md)
 - [ApiPolicyWaiverRequestOptionsDTO](docs/ApiPolicyWaiverRequestOptionsDTO.md)
 - [ApiPolicyWaiverRequestReviewDTO](docs/ApiPolicyWaiverRequestReviewDTO.md)
 - [ApiPolicyWaiverRequestsApplicableToViolationDTO](docs/ApiPolicyWaiverRequestsApplicableToViolationDTO.md)
 - [ApiPolicyWaiversApplicableToViolationDTO](docs/ApiPolicyWaiversApplicableToViolationDTO.md)
 - [ApiPromoteScanRequestDTOV2](docs/ApiPromoteScanRequestDTOV2.md)
 - [ApiProxyServerConfigurationDTO](docs/ApiProxyServerConfigurationDTO.md)
 - [ApiPullRequestResult](docs/ApiPullRequestResult.md)
 - [ApiPullRequestResults](docs/ApiPullRequestResults.md)
 - [ApiReportComponentDTOV2](docs/ApiReportComponentDTOV2.md)
 - [ApiReportComponentPolicyViolationsDTOV2](docs/ApiReportComponentPolicyViolationsDTOV2.md)
 - [ApiReportConstraintConditionDTOV2](docs/ApiReportConstraintConditionDTOV2.md)
 - [ApiReportConstraintViolationDTOV2](docs/ApiReportConstraintViolationDTOV2.md)
 - [ApiReportHistoryDTO](docs/ApiReportHistoryDTO.md)
 - [ApiReportPolicyDataDTOV2](docs/ApiReportPolicyDataDTOV2.md)
 - [ApiReportPolicyViolationDTOV2](docs/ApiReportPolicyViolationDTOV2.md)
 - [ApiReportRawDataDTOV2](docs/ApiReportRawDataDTOV2.md)
 - [ApiReportResultsDTO](docs/ApiReportResultsDTO.md)
 - [ApiReportRetentionPoliciesDTO](docs/ApiReportRetentionPoliciesDTO.md)
 - [ApiReportRetentionPolicyDTO](docs/ApiReportRetentionPolicyDTO.md)
 - [ApiRepositoryComponentDTO](docs/ApiRepositoryComponentDTO.md)
 - [ApiRepositoryComponentEvaluationRequest](docs/ApiRepositoryComponentEvaluationRequest.md)
 - [ApiRepositoryComponentEvaluationRequestList](docs/ApiRepositoryComponentEvaluationRequestList.md)
 - [ApiRepositoryComponentEvaluationResult](docs/ApiRepositoryComponentEvaluationResult.md)
 - [ApiRepositoryComponentEvaluationResultList](docs/ApiRepositoryComponentEvaluationResultList.md)
 - [ApiRepositoryComponentPath](docs/ApiRepositoryComponentPath.md)
 - [ApiRepositoryComponentPolicyViolationDTO](docs/ApiRepositoryComponentPolicyViolationDTO.md)
 - [ApiRepositoryComponentsInQuarantineDTO](docs/ApiRepositoryComponentsInQuarantineDTO.md)
 - [ApiRepositoryContainerDTO](docs/ApiRepositoryContainerDTO.md)
 - [ApiRepositoryDTO](docs/ApiRepositoryDTO.md)
 - [ApiRepositoryListDTO](docs/ApiRepositoryListDTO.md)
 - [ApiRepositoryManagerDTO](docs/ApiRepositoryManagerDTO.md)
 - [ApiRepositoryManagerListDTO](docs/ApiRepositoryManagerListDTO.md)
 - [ApiRepositoryPathResponseDTO](docs/ApiRepositoryPathResponseDTO.md)
 - [ApiRepositoryPathVersions](docs/ApiRepositoryPathVersions.md)
 - [ApiRepositoryWaiverDTO](docs/ApiRepositoryWaiverDTO.md)
 - [ApiRequestPolicyWaiverDTO](docs/ApiRequestPolicyWaiverDTO.md)
 - [ApiReverseProxyAuthenticationConfigurationDTO](docs/ApiReverseProxyAuthenticationConfigurationDTO.md)
 - [ApiRoleDTO](docs/ApiRoleDTO.md)
 - [ApiRoleListDTO](docs/ApiRoleListDTO.md)
 - [ApiRoleMemberMappingDTO](docs/ApiRoleMemberMappingDTO.md)
 - [ApiRoleMemberMappingListDTO](docs/ApiRoleMemberMappingListDTO.md)
 - [ApiSamlConfigurationDTO](docs/ApiSamlConfigurationDTO.md)
 - [ApiSamlConfigurationResponseDTO](docs/ApiSamlConfigurationResponseDTO.md)
 - [ApiSearchCriteriaDTOV2](docs/ApiSearchCriteriaDTOV2.md)
 - [ApiSearchResultDTOV2](docs/ApiSearchResultDTOV2.md)
 - [ApiSearchResultsDTOV2](docs/ApiSearchResultsDTOV2.md)
 - [ApiSecurityDataDTO](docs/ApiSecurityDataDTO.md)
 - [ApiSecurityIssueAnalysisDTO](docs/ApiSecurityIssueAnalysisDTO.md)
 - [ApiSecurityIssueDTO](docs/ApiSecurityIssueDTO.md)
 - [ApiSecurityVulnerabilityOverrideDTOV2](docs/ApiSecurityVulnerabilityOverrideDTOV2.md)
 - [ApiSecurityVulnerabilityOverrideResponseDTOV2](docs/ApiSecurityVulnerabilityOverrideResponseDTOV2.md)
 - [ApiSourceControlConfigurationDTO](docs/ApiSourceControlConfigurationDTO.md)
 - [ApiSourceControlDTO](docs/ApiSourceControlDTO.md)
 - [ApiSourceControlEvaluationRequestDTO](docs/ApiSourceControlEvaluationRequestDTO.md)
 - [ApiStagePolicyViolationComponentDTO](docs/ApiStagePolicyViolationComponentDTO.md)
 - [ApiStaleApplicationEvaluationDTO](docs/ApiStaleApplicationEvaluationDTO.md)
 - [ApiStaleEvaluationStageDTO](docs/ApiStaleEvaluationStageDTO.md)
 - [ApiStaleEvaluationsDTO](docs/ApiStaleEvaluationsDTO.md)
 - [ApiStaleRepositoryEvaluationDTO](docs/ApiStaleRepositoryEvaluationDTO.md)
 - [ApiStaleWaiverDTO](docs/ApiStaleWaiverDTO.md)
 - [ApiStaleWaiversResponseDTO](docs/ApiStaleWaiversResponseDTO.md)
 - [ApiStatusDTO](docs/ApiStatusDTO.md)
 - [ApiSuccessMetricsRetentionPolicyDTO](docs/ApiSuccessMetricsRetentionPolicyDTO.md)
 - [ApiSuggestedVersionChangeOptionDTO](docs/ApiSuggestedVersionChangeOptionDTO.md)
 - [ApiTagDTO](docs/ApiTagDTO.md)
 - [ApiThirdPartyScanResultDTO](docs/ApiThirdPartyScanResultDTO.md)
 - [ApiThirdPartyScanTicketDTO](docs/ApiThirdPartyScanTicketDTO.md)
 - [ApiUserDTO](docs/ApiUserDTO.md)
 - [ApiUserListDTO](docs/ApiUserListDTO.md)
 - [ApiUserTokenDTO](docs/ApiUserTokenDTO.md)
 - [ApiUserTokenExistsDTO](docs/ApiUserTokenExistsDTO.md)
 - [ApiVersionChangeOptionDTO](docs/ApiVersionChangeOptionDTO.md)
 - [ApiWaivedPolicyViolationDTO](docs/ApiWaivedPolicyViolationDTO.md)
 - [ApiWaiverOptionsDTO](docs/ApiWaiverOptionsDTO.md)
 - [ApiZScalerConfigurationDTO](docs/ApiZScalerConfigurationDTO.md)
 - [ApiZScalerQuotaDTO](docs/ApiZScalerQuotaDTO.md)
 - [ApplicableContext](docs/ApplicableContext.md)
 - [ApplicableLabels](docs/ApplicableLabels.md)
 - [ApplicableTagsDTO](docs/ApplicableTagsDTO.md)
 - [ApplicationTag](docs/ApplicationTag.md)
 - [ApplicationTagsByOwnerDTO](docs/ApplicationTagsByOwnerDTO.md)
 - [AppliedTagsDTO](docs/AppliedTagsDTO.md)
 - [AttachmentText](docs/AttachmentText.md)
 - [AttributionReportTemplateDTO](docs/AttributionReportTemplateDTO.md)
 - [BulkSecurityVulnerabilityDataDTO](docs/BulkSecurityVulnerabilityDataDTO.md)
 - [ComponentDisplayName](docs/ComponentDisplayName.md)
 - [ComponentDisplayNamePart](docs/ComponentDisplayNamePart.md)
 - [ComponentFact](docs/ComponentFact.md)
 - [ComponentIdentifier](docs/ComponentIdentifier.md)
 - [ComponentLocator](docs/ComponentLocator.md)
 - [ComponentObligationAttributionDTO](docs/ComponentObligationAttributionDTO.md)
 - [ConditionFact](docs/ConditionFact.md)
 - [ConfigurationValidationResult](docs/ConfigurationValidationResult.md)
 - [ConstraintFact](docs/ConstraintFact.md)
 - [ContainerImageInQuarantineData](docs/ContainerImageInQuarantineData.md)
 - [ContainerImageInQuarantineDataResult](docs/ContainerImageInQuarantineDataResult.md)
 - [CpeMatchingConfigurationRequest](docs/CpeMatchingConfigurationRequest.md)
 - [CweId](docs/CweId.md)
 - [CweIdDTO](docs/CweIdDTO.md)
 - [DevelopmentPrioritizationResults](docs/DevelopmentPrioritizationResults.md)
 - [EpssData](docs/EpssData.md)
 - [GetSuggestedRemediationForComponent200Response](docs/GetSuggestedRemediationForComponent200Response.md)
 - [GroupingByDTO](docs/GroupingByDTO.md)
 - [ImportSbomRequest](docs/ImportSbomRequest.md)
 - [InnerSourceData](docs/InnerSourceData.md)
 - [InsertOrUpdateSamlConfigurationRequest](docs/InsertOrUpdateSamlConfigurationRequest.md)
 - [InstallLicenseRequest](docs/InstallLicenseRequest.md)
 - [KevData](docs/KevData.md)
 - [LabelsByOwner](docs/LabelsByOwner.md)
 - [LegalSourceLinkDTO](docs/LegalSourceLinkDTO.md)
 - [LicenseObligationDTO](docs/LicenseObligationDTO.md)
 - [LicenseOverride](docs/LicenseOverride.md)
 - [LicenseOverrideByOwner](docs/LicenseOverrideByOwner.md)
 - [LicenseThreatGroupDTO](docs/LicenseThreatGroupDTO.md)
 - [MalwareCategory](docs/MalwareCategory.md)
 - [MalwareDefenseData](docs/MalwareDefenseData.md)
 - [MalwareDefenseResponseList](docs/MalwareDefenseResponseList.md)
 - [MoveOrganizationResponseDTO](docs/MoveOrganizationResponseDTO.md)
 - [PolicyAlert](docs/PolicyAlert.md)
 - [PolicyContainerWaiverData](docs/PolicyContainerWaiverData.md)
 - [PolicyContainerWaiverDataResult](docs/PolicyContainerWaiverDataResult.md)
 - [PolicyEvaluationResult](docs/PolicyEvaluationResult.md)
 - [PolicyFact](docs/PolicyFact.md)
 - [PolicyOwner](docs/PolicyOwner.md)
 - [PolicyTag](docs/PolicyTag.md)
 - [PrioritizedComponent](docs/PrioritizedComponent.md)
 - [ReferenceLink](docs/ReferenceLink.md)
 - [ReferenceLinkDTO](docs/ReferenceLinkDTO.md)
 - [RootCause](docs/RootCause.md)
 - [RootCauseDTO](docs/RootCauseDTO.md)
 - [SCMUserMappingsDTO](docs/SCMUserMappingsDTO.md)
 - [SCMUserMappingsResponseDTO](docs/SCMUserMappingsResponseDTO.md)
 - [SCMUserMatchingResultDTO](docs/SCMUserMatchingResultDTO.md)
 - [SbomVulnerabilityAnalysisRequest](docs/SbomVulnerabilityAnalysisRequest.md)
 - [SearchResultDTO](docs/SearchResultDTO.md)
 - [SearchResultItemDTO](docs/SearchResultItemDTO.md)
 - [SecurityVulnerabilityCustomData](docs/SecurityVulnerabilityCustomData.md)
 - [SecurityVulnerabilityCustomDataDTO](docs/SecurityVulnerabilityCustomDataDTO.md)
 - [SecurityVulnerabilityData](docs/SecurityVulnerabilityData.md)
 - [SecurityVulnerabilityDataDTO](docs/SecurityVulnerabilityDataDTO.md)
 - [SecurityVulnerabilitySeverity](docs/SecurityVulnerabilitySeverity.md)
 - [SecurityVulnerabilitySeverityDTO](docs/SecurityVulnerabilitySeverityDTO.md)
 - [SecurityVulnerabilityWeakness](docs/SecurityVulnerabilityWeakness.md)
 - [SecurityVulnerabilityWeaknessDTO](docs/SecurityVulnerabilityWeaknessDTO.md)
 - [StageData](docs/StageData.md)
 - [Swid](docs/Swid.md)
 - [SystemConfig](docs/SystemConfig.md)
 - [SystemConfigProperty](docs/SystemConfigProperty.md)
 - [TagsByOwnerDTO](docs/TagsByOwnerDTO.md)
 - [TriggerReference](docs/TriggerReference.md)
 - [UserMapping](docs/UserMapping.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationResult](docs/ValidationResult.md)
 - [ValidationWarning](docs/ValidationWarning.md)
 - [VulnerabilityAnalysis](docs/VulnerabilityAnalysis.md)
 - [VulnerabilitySource](docs/VulnerabilitySource.md)
 - [VulnerabilitySourceDTO](docs/VulnerabilitySourceDTO.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BasicAuth"></a>
### BasicAuth

- **Type**: HTTP basic authentication


## Author

community@sonatype.com


